==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/PasswordPolicyPasswordSettings.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PasswordPolicyPasswordSettingsAge;
import com.okta.sdk.resource.model.PasswordPolicyPasswordSettingsComplexity;
import com.okta.sdk.resource.model.PasswordPolicyPasswordSettingsLockout;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PasswordPolicyPasswordSettings
 */
@JsonPropertyOrder({ PasswordPolicyPasswordSettings.JSON_PROPERTY_AGE,
        PasswordPolicyPasswordSettings.JSON_PROPERTY_COMPLEXITY, PasswordPolicyPasswordSettings.JSON_PROPERTY_LOCKOUT })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PasswordPolicyPasswordSettings implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_AGE = "age";
    private PasswordPolicyPasswordSettingsAge age;

    public static final String JSON_PROPERTY_COMPLEXITY = "complexity";
    private PasswordPolicyPasswordSettingsComplexity complexity;

    public static final String JSON_PROPERTY_LOCKOUT = "lockout";
    private PasswordPolicyPasswordSettingsLockout lockout;

    public PasswordPolicyPasswordSettings() {
    }

    public PasswordPolicyPasswordSettings age(PasswordPolicyPasswordSettingsAge age) {

        this.age = age;
        return this;
    }

    /**
     * Get age
     *
     * @return age
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_AGE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordPolicyPasswordSettingsAge getAge() {
        return age;
    }

    @JsonProperty(JSON_PROPERTY_AGE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAge(PasswordPolicyPasswordSettingsAge age) {
        this.age = age;
    }

    public PasswordPolicyPasswordSettings complexity(PasswordPolicyPasswordSettingsComplexity complexity) {

        this.complexity = complexity;
        return this;
    }

    /**
     * Get complexity
     *
     * @return complexity
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_COMPLEXITY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordPolicyPasswordSettingsComplexity getComplexity() {
        return complexity;
    }

    @JsonProperty(JSON_PROPERTY_COMPLEXITY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setComplexity(PasswordPolicyPasswordSettingsComplexity complexity) {
        this.complexity = complexity;
    }

    public PasswordPolicyPasswordSettings lockout(PasswordPolicyPasswordSettingsLockout lockout) {

        this.lockout = lockout;
        return this;
    }

    /**
     * Get lockout
     *
     * @return lockout
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LOCKOUT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordPolicyPasswordSettingsLockout getLockout() {
        return lockout;
    }

    @JsonProperty(JSON_PROPERTY_LOCKOUT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLockout(PasswordPolicyPasswordSettingsLockout lockout) {
        this.lockout = lockout;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PasswordPolicyPasswordSettings passwordPolicyPasswordSettings = (PasswordPolicyPasswordSettings) o;
        return Objects.equals(this.age, passwordPolicyPasswordSettings.age)
                && Objects.equals(this.complexity, passwordPolicyPasswordSettings.complexity)
                && Objects.equals(this.lockout, passwordPolicyPasswordSettings.lockout);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(age, complexity, lockout);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PasswordPolicyPasswordSettings {\n");
        sb.append("    age: ").append(toIndentedString(age)).append("\n");
        sb.append("    complexity: ").append(toIndentedString(complexity)).append("\n");
        sb.append("    lockout: ").append(toIndentedString(lockout)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/PasswordPolicyPasswordSettings.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PasswordPolicyPasswordSettingsAge;
import com.okta.sdk.resource.model.PasswordPolicyPasswordSettingsComplexity;
import com.okta.sdk.resource.model.PasswordPolicyPasswordSettingsLockout;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PasswordPolicyPasswordSettings
 */
@JsonPropertyOrder({ PasswordPolicyPasswordSettings.JSON_PROPERTY_AGE,
        PasswordPolicyPasswordSettings.JSON_PROPERTY_COMPLEXITY, PasswordPolicyPasswordSettings.JSON_PROPERTY_LOCKOUT })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PasswordPolicyPasswordSettings implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_AGE = "age";
    private PasswordPolicyPasswordSettingsAge age;

    public static final String JSON_PROPERTY_COMPLEXITY = "complexity";
    private PasswordPolicyPasswordSettingsComplexity complexity;

    public static final String JSON_PROPERTY_LOCKOUT = "lockout";
    private PasswordPolicyPasswordSettingsLockout lockout;

    public PasswordPolicyPasswordSettings() {
    }

    public PasswordPolicyPasswordSettings age(PasswordPolicyPasswordSettingsAge age) {

        this.age = age;
        return this;
    }

    /**
     * Get age
     *
     * @return age
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_AGE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordPolicyPasswordSettingsAge getAge() {
        return age;
    }

    @JsonProperty(JSON_PROPERTY_AGE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAge(PasswordPolicyPasswordSettingsAge age) {
        this.age = age;
    }

    public PasswordPolicyPasswordSettings complexity(PasswordPolicyPasswordSettingsComplexity complexity) {

        this.complexity = complexity;
        return this;
    }

    /**
     * Get complexity
     *
     * @return complexity
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_COMPLEXITY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordPolicyPasswordSettingsComplexity getComplexity() {
        return complexity;
    }

    @JsonProperty(JSON_PROPERTY_COMPLEXITY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setComplexity(PasswordPolicyPasswordSettingsComplexity complexity) {
        this.complexity = complexity;
    }

    public PasswordPolicyPasswordSettings lockout(PasswordPolicyPasswordSettingsLockout lockout) {

        this.lockout = lockout;
        return this;
    }

    /**
     * Get lockout
     *
     * @return lockout
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LOCKOUT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordPolicyPasswordSettingsLockout getLockout() {
        return lockout;
    }

    @JsonProperty(JSON_PROPERTY_LOCKOUT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLockout(PasswordPolicyPasswordSettingsLockout lockout) {
        this.lockout = lockout;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PasswordPolicyPasswordSettings passwordPolicyPasswordSettings = (PasswordPolicyPasswordSettings) o;
        return Objects.equals(this.age, passwordPolicyPasswordSettings.age)
                && Objects.equals(this.complexity, passwordPolicyPasswordSettings.complexity)
                && Objects.equals(this.lockout, passwordPolicyPasswordSettings.lockout);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(age, complexity, lockout);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PasswordPolicyPasswordSettings {\n");
        sb.append("    age: ").append(toIndentedString(age)).append("\n");
        sb.append("    complexity: ").append(toIndentedString(complexity)).append("\n");
        sb.append("    lockout: ").append(toIndentedString(lockout)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
